==> knative-model-6.4.0-sources.jar: io/fabric8/knative/eventing/contrib/awssqs/v1alpha1/AwsSqsSourceFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.awssqs.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AwsSqsSourceFluentImpl<A extends AwsSqsSourceFluent<A>> extends BaseFluent<A> implements AwsSqsSourceFluent<A>{
  public AwsSqsSourceFluentImpl() {
  }
  public AwsSqsSourceFluentImpl(AwsSqsSource instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private AwsSqsSourceSpecBuilder spec;
  private AwsSqsSourceStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public AwsSqsSourceFluent.MetadataNested<A> withNewMetadata() {
    return new AwsSqsSourceFluentImpl.MetadataNestedImpl();
  }
  public AwsSqsSourceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new AwsSqsSourceFluentImpl.MetadataNestedImpl(item);
  }
  public AwsSqsSourceFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public AwsSqsSourceFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public AwsSqsSourceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public AwsSqsSourceSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public AwsSqsSourceSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(AwsSqsSourceSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new AwsSqsSourceSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public AwsSqsSourceFluent.SpecNested<A> withNewSpec() {
    return new AwsSqsSourceFluentImpl.SpecNestedImpl();
  }
  public AwsSqsSourceFluent.SpecNested<A> withNewSpecLike(AwsSqsSourceSpec item) {
    return new AwsSqsSourceFluentImpl.SpecNestedImpl(item);
  }
  public AwsSqsSourceFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public AwsSqsSourceFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new AwsSqsSourceSpecBuilder().build());
  }
  public AwsSqsSourceFluent.SpecNested<A> editOrNewSpecLike(AwsSqsSourceSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public AwsSqsSourceStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public AwsSqsSourceStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(AwsSqsSourceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new AwsSqsSourceStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public AwsSqsSourceFluent.StatusNested<A> withNewStatus() {
    return new AwsSqsSourceFluentImpl.StatusNestedImpl();
  }
  public AwsSqsSourceFluent.StatusNested<A> withNewStatusLike(AwsSqsSourceStatus item) {
    return new AwsSqsSourceFluentImpl.StatusNestedImpl(item);
  }
  public AwsSqsSourceFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public AwsSqsSourceFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new AwsSqsSourceStatusBuilder().build());
  }
  public AwsSqsSourceFluent.StatusNested<A> editOrNewStatusLike(AwsSqsSourceStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AwsSqsSourceFluentImpl that = (AwsSqsSourceFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<AwsSqsSourceFluent.MetadataNested<N>> implements AwsSqsSourceFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) AwsSqsSourceFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends AwsSqsSourceSpecFluentImpl<AwsSqsSourceFluent.SpecNested<N>> implements AwsSqsSourceFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(AwsSqsSourceSpec item) {
      this.builder = new AwsSqsSourceSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new AwsSqsSourceSpecBuilder(this);
    }
    AwsSqsSourceSpecBuilder builder;
    public N and() {
      return (N) AwsSqsSourceFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends AwsSqsSourceStatusFluentImpl<AwsSqsSourceFluent.StatusNested<N>> implements AwsSqsSourceFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(AwsSqsSourceStatus item) {
      this.builder = new AwsSqsSourceStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new AwsSqsSourceStatusBuilder(this);
    }
    AwsSqsSourceStatusBuilder builder;
    public N and() {
      return (N) AwsSqsSourceFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/awssqs/v1alpha1/AwsSqsSourceFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.awssqs.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AwsSqsSourceFluentImpl<A extends AwsSqsSourceFluent<A>> extends BaseFluent<A> implements AwsSqsSourceFluent<A>{
  public AwsSqsSourceFluentImpl() {
  }
  public AwsSqsSourceFluentImpl(AwsSqsSource instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private AwsSqsSourceSpecBuilder spec;
  private AwsSqsSourceStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public AwsSqsSourceFluentImpl.MetadataNested<A> withNewMetadata() {
    return new AwsSqsSourceFluentImpl.MetadataNestedImpl();
  }
  public AwsSqsSourceFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new AwsSqsSourceFluentImpl.MetadataNestedImpl(item);
  }
  public AwsSqsSourceFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public AwsSqsSourceFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public AwsSqsSourceFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public AwsSqsSourceSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public AwsSqsSourceSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(AwsSqsSourceSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new AwsSqsSourceSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public AwsSqsSourceFluentImpl.SpecNested<A> withNewSpec() {
    return new AwsSqsSourceFluentImpl.SpecNestedImpl();
  }
  public AwsSqsSourceFluentImpl.SpecNested<A> withNewSpecLike(AwsSqsSourceSpec item) {
    return new AwsSqsSourceFluentImpl.SpecNestedImpl(item);
  }
  public AwsSqsSourceFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public AwsSqsSourceFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new AwsSqsSourceSpecBuilder().build());
  }
  public AwsSqsSourceFluentImpl.SpecNested<A> editOrNewSpecLike(AwsSqsSourceSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public AwsSqsSourceStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public AwsSqsSourceStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(AwsSqsSourceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new AwsSqsSourceStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public AwsSqsSourceFluentImpl.StatusNested<A> withNewStatus() {
    return new AwsSqsSourceFluentImpl.StatusNestedImpl();
  }
  public AwsSqsSourceFluentImpl.StatusNested<A> withNewStatusLike(AwsSqsSourceStatus item) {
    return new AwsSqsSourceFluentImpl.StatusNestedImpl(item);
  }
  public AwsSqsSourceFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public AwsSqsSourceFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new AwsSqsSourceStatusBuilder().build());
  }
  public AwsSqsSourceFluentImpl.StatusNested<A> editOrNewStatusLike(AwsSqsSourceStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AwsSqsSourceFluentImpl that = (AwsSqsSourceFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<AwsSqsSourceFluentImpl.MetadataNested<N>> implements AwsSqsSourceFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) AwsSqsSourceFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends AwsSqsSourceSpecFluentImpl<AwsSqsSourceFluentImpl.SpecNested<N>> implements AwsSqsSourceFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(AwsSqsSourceSpec item) {
      this.builder = new AwsSqsSourceSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new AwsSqsSourceSpecBuilder(this);
    }
    AwsSqsSourceSpecBuilder builder;
    public N and() {
      return (N) AwsSqsSourceFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends AwsSqsSourceStatusFluentImpl<AwsSqsSourceFluentImpl.StatusNested<N>> implements AwsSqsSourceFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(AwsSqsSourceStatus item) {
      this.builder = new AwsSqsSourceStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new AwsSqsSourceStatusBuilder(this);
    }
    AwsSqsSourceStatusBuilder builder;
    public N and() {
      return (N) AwsSqsSourceFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
